@@ -382,7 +382,13 @@ Changelog:
  *   0.9.21  2022-09-19  Minor clean-up / add wheels to distro
  *   0.9.22  2022-09027  Issue #43 (0.9.21 Raises TypeError instead of DNSError when failing to parse HTTPS records)
                          Note that we just fix the exception - there still seems to be a problem with parsing HTTPS records
-                         (Thnaks to @robinlandstrom)
+                         (Thanks to @robinlandstrom)
+ *   0.9.23  2022-10-28  Issue #43: HTTPS reads after RD end (thanks to @robinlandstrom for pull request)
+                         Issue #45: Dnslib fails to handle unknown RR types in NSEC RD type bitmap
+                            Bimap now supports a function to map unknown types which we use to
+                            dynamically map from rtype <-> TYPExxxx for unknown record types
+                            RR zone representation updated to match RFC3597
+                         Pull Request #47: Add support for DS, SSHFP, and TLSA records (thanks to @rmbolger)
 
 License:
 --------
@@ -405,7 +411,7 @@ Master Repository/Issues:
 
 from dnslib.dns import *
 
-version = "0.9.22"
+version = "0.9.23"
 
 if __name__ == '__main__':
     import doctest,sys,textwrap
