@@ -4,11 +4,11 @@
     digparser
     ---------
 
-    Encode/decode DNS packets from DiG textual representation. Parses 
-    question (if present: +qr flag) & answer sections and returns list 
+    Encode/decode DNS packets from DiG textual representation. Parses
+    question (if present: +qr flag) & answer sections and returns list
     of DNSRecord objects.
 
-    Unsupported RR types are skipped (this is different from the packet 
+    Unsupported RR types are skipped (this is different from the packet
     parser which will store and encode the RDATA as a binary blob)
 
     >>> dig = os.path.join(os.path.dirname(__file__),"test","dig","google.com-A.dig")
@@ -89,7 +89,7 @@ class DigParser:
         self.l.commentchars = ';'
         self.l.nltok = ('NL',None)
         self.i = iter(self.l)
-        
+
     def parseHeader(self,l1,l2):
         _,_,_,opcode,_,status,_,_id = l1.split()
         _,flags,_ = l2.split(';')
@@ -164,14 +164,15 @@ class DigParser:
             while True:
                 tok,val = next(self.i)
                 if tok == 'COMMENT':
-                    if 'Sending:' in val or 'Got answer:' in val:
+                    if val.startswith('; ->>HEADER<<-'):
+                        # Start new record
                         if dns:
+                            # If we have a current record complete this
                             self.parseQuestions(q,dns)
                             self.parseAnswers(a,auth,ar,dns)
                             yield(dns)
                         dns = DNSRecord()
                         q,a,auth,ar = [],[],[],[]
-                    elif val.startswith('; ->>HEADER<<-'):
                         self.expect('NL')
                         val2 = self.expect('COMMENT')
                         dns.header = self.parseHeader(val,val2)
@@ -229,4 +230,4 @@ if __name__ == '__main__':
         for record in l:
             print(repr(record))
     else:
-        doctest.testmod()
+        sys.exit(0 if doctest.testmod().failed == 0 else 1)
